stun_agent

Enum StunAgentError

source
pub enum StunAgentError {
    Discarded,
    FingerPrintValidationFailed,
    Ignored,
    MaxOutstandingRequestsReached,
    StunCheckFailed,
    InternalError(String),
}
Describes the error that can occur during the STUN agent operation.

Variants



Discarded

Indicates that the STUN agent has discarded the buffer



FingerPrintValidationFailed

Indicates that the STUN agent has received an invalid STUN packet



Ignored

Indicates that the STUN agent has ignored the operation



MaxOutstandingRequestsReached

Indicates that the STUN agent has reached the maximum number of outstanding requests



StunCheckFailed

Indicates that the STUN agent has received an invalid STUN packet



InternalError(String)

Indicates that the STUN agent has detected an internal error, and the String contains the error message