pub enum StunPacketDecodedValue {
Decoded((StunPacket, usize)),
MoreBytesNeeded((StunPacketDecoder, Option<usize>)),
}Expand description
Describes the possible outcomes of the STUN packet decoding.
- If the STUN packet has been fully decoded, the method returns the decoded STUN packet and the number of bytes consumed.
- If the STUN packet has not been fully decoded, the method returns the decoder and the number of bytes still needed to complete the STUN packet, if known.
Variants
Decoded((StunPacket, usize))
Returns the decoded STUN packet and the number of bytes consumed from the input.
MoreBytesNeeded((StunPacketDecoder, Option<usize>))
Returns the decoder and the number of bytes missing to complete the STUN packet if known.