pub enum StunPacketErrorType {
SmallBuffer,
InvalidStunPacket,
}Expand description
Describe the error type that can occur during the STUN packet decoding.
Variants
SmallBuffer
The buffer is too small to hold the STUN packet.
InvalidStunPacket
The buffer does not contain a valid STUN header.