pub enum StuntClientEvent {
OutputPacket(StunPacket),
RestransmissionTimeOut((TransactionId, Duration)),
Retry(TransactionId),
TransactionFailed((TransactionId, StunTransactionError)),
StunMessageReceived(StunMessage),
}Expand description
Stun client events
Variants
OutputPacket(StunPacket)
Notification used by the STUN client to send a STUN packet to the server
RestransmissionTimeOut((TransactionId, Duration))
This event sets a timeout for a transaction identified by the TransactionId.
Once the timeout is reached, the client must call the on_timeout method on
the StunClient instance.
If multiple timeouts are scheduled for different outgoing transactions,
the client will only be notified about the most recent timeout.
Retry(TransactionId)
Notification used to retry a transaction identified by the TransactionId.
TransactionFailed((TransactionId, StunTransactionError))
Event used by the STUN client to notify that a transaction identified by the TransactionId
has failed. The StunTransactionError indicates the reason of the failure.
StunMessageReceived(StunMessage)
Event used by the STUN client to notify that a STUN message has been received.