pub enum CredentialMechanism {
ShortTerm(Option<Integrity>),
LongTerm,
}Expand description
Describes the kind of credential mechanism that can be used by the STUN agent.
Variants
ShortTerm(Option<Integrity>)
Short-term credential mechanism
with the specified Integrity in case the agent knows from an external mechanism
which message integrity algorithm is supported by both agents.
LongTerm