pub struct StunAttributes { /* private fields */ }Expand description
Even though the STUN message is a collection of attributes, The StunAttribute is used to
simplify the addition and removal of attributes. The
RFC8489 does not set neither a
limit nor a specific order for the attributes that can be added to a message, nevertheless,
there are certain restrictions that must be followed for the integrity and fingerprint
attributes. The StunAttribute eases the manipulation of attributes
while ensuring that the above restrictions are met.
Implementations
sourceimpl StunAttributes
impl StunAttributes
sourcepub fn add<T>(&mut self, attribute: T)where
T: Into<StunAttribute>,
pub fn add<T>(&mut self, attribute: T)where
T: Into<StunAttribute>,
Adds a STUN attribute to the collection. If the attribute is already present, it will be replaced.
sourcepub fn remove<T>(&mut self) -> Option<StunAttribute>where
T: StunAttributeType,
pub fn remove<T>(&mut self) -> Option<StunAttribute>where
T: StunAttributeType,